import os
import sys

os.environ["DJANGO_SETTINGS_MODULE"] = "tests.settings"

try:
    from django.conf import settings
    from django.test.utils import get_runner

    try:
        import django

        setup = django.setup
    except AttributeError:
        pass
    else:
        setup()

except ImportError:
    import traceback

    traceback.print_exc()
    raise ImportError("To fix this error, run: pip install -r requirements-test.txt")


def run_tests(*test_args):
    if not test_args:
        test_args = ["tests"]

    # Run tests
    TestRunner = get_runner(settings)
    test_runner = TestRunner()

    failures = test_runner.run_tests(test_args)

    if failures:
        sys.exit(bool(failures))


if __name__ == "__main__":
    run_tests(*sys.argv[1:])



from teryt_tree.models import JednostkaAdministracyjna
from django_filters.filters import ModelChoiceFilter
from django.utils.translation import ugettext as _


class AreaFilter(ModelChoiceFilter):
    def __init__(self, *args, **kwargs):
        label = kwargs.pop("label", _("Area"))
        required = kwargs.pop("required", False)
        queryset = kwargs.pop("queryset", JednostkaAdministracyjna.objects.all())
        action = kwargs.pop("method", lambda q, _, v: q.area(v))
        super(ModelChoiceFilter, self).__init__(
            *args,
            label=label,
            required=required,
            queryset=queryset,
            method=action,
            **kwargs
        )


class VoivodeshipFilter(AreaFilter):
    def __init__(self, *args, **kwargs):
        label = kwargs.pop("label", _("Voivodeship"))
        queryset = kwargs.pop(
            "queryset", JednostkaAdministracyjna.objects.voivodeship().all()
        )
        super().__init__(*args, label=label, queryset=queryset, **kwargs)


class CountyFilter(AreaFilter):
    def __init__(self, *args, **kwargs):
        label = kwargs.pop("label", _("County"))
        queryset = kwargs.pop(
            "queryset", JednostkaAdministracyjna.objects.county().all()
        )
        super().__init__(*args, label=label, queryset=queryset, **kwargs)


class CommunityFilter(AreaFilter):
    def __init__(self, *args, **kwargs):
        label = kwargs.pop("label", _("Community"))
        queryset = kwargs.pop(
            "queryset", JednostkaAdministracyjna.objects.community().all()
        )
        super().__init__(*args, label=label, queryset=queryset, **kwargs)



from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="category",
            options={"verbose_name": "Category", "verbose_name_plural": "Categories"},
        ),
        migrations.AlterModelOptions(
            name="jednostkaadministracyjna",
            options={
                "verbose_name": "Unit of administrative division",
                "verbose_name_plural": "Units of administrative division",
            },
        ),
        migrations.AlterField(
            model_name="category",
            name="level",
            field=models.IntegerField(
                db_index=True,
                choices=[(1, "voivodeship"), (2, "county"), (3, "community")],
            ),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="updated_on",
            field=models.DateField(verbose_name="Updated date"),
        ),
    ]



from teryt_tree import factories
from django.test import TestCase


class JednostkaAdministracyjnaFactoryTestCase(TestCase):
    def test_parent_settings(self):
        obj1 = factories.JednostkaAdministracyjnaFactory()
        obj2 = factories.JednostkaAdministracyjnaFactory(parent=obj1)
        self.assertEqual(obj1.level, 0)
        self.assertEqual(obj2.level, 1)
        self.assertEqual(obj2.parent, obj1)



from django.db import migrations, models
import django.db.models.deletion
import autoslug.fields
import mptt.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Category",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("name", models.CharField(max_length=50)),
                (
                    "slug",
                    autoslug.fields.AutoSlugField(
                        populate_from=b"name", editable=False
                    ),
                ),
                (
                    "level",
                    models.IntegerField(
                        db_index=True,
                        choices=[(1, "wojew\xf3dztwo"), (2, "powiat"), (3, "gmina")],
                    ),
                ),
            ],
            options={"verbose_name": "Kategoria", "verbose_name_plural": "Kategorie",},
        ),
        migrations.CreateModel(
            name="JednostkaAdministracyjna",
            fields=[
                (
                    "id",
                    models.CharField(max_length=7, serialize=False, primary_key=True),
                ),
                ("name", models.CharField(max_length=36, verbose_name="Nazwa")),
                (
                    "slug",
                    autoslug.fields.AutoSlugField(
                        populate_from=b"name", unique=True, editable=False
                    ),
                ),
                ("updated_on", models.DateField(verbose_name="Data aktualizacji")),
                ("active", models.BooleanField(default=False)),
                ("lft", models.PositiveIntegerField(editable=False, db_index=True)),
                ("rght", models.PositiveIntegerField(editable=False, db_index=True)),
                ("tree_id", models.PositiveIntegerField(editable=False, db_index=True)),
                ("level", models.PositiveIntegerField(editable=False, db_index=True)),
                (
                    "category",
                    models.ForeignKey(
                        to="teryt_tree.Category",
                        on_delete=django.db.models.deletion.CASCADE,
                    ),
                ),
                (
                    "parent",
                    mptt.fields.TreeForeignKey(
                        related_name="children",
                        on_delete=django.db.models.deletion.CASCADE,
                        blank=True,
                        to="teryt_tree.JednostkaAdministracyjna",
                        null=True,
                    ),
                ),
            ],
            options={
                "verbose_name": "Jednostka podzia\u0142u terytorialnego",
                "verbose_name_plural": "Jednostki podzia\u0142u terytorialnego",
            },
        ),
    ]



from dal import autocomplete
from teryt_tree.models import JednostkaAdministracyjna


class VoivodeshipAutocomplete(autocomplete.Select2QuerySetView):
    def get_queryset(self):
        qs = JednostkaAdministracyjna.objects.voivodeship().all()

        if self.q:
            qs = qs.filter(name__istartswith=self.q)
        return qs


class CountyAutocomplete(autocomplete.Select2QuerySetView):
    def get_queryset(self):
        qs = JednostkaAdministracyjna.objects.county().all()

        if self.q:
            qs = qs.filter(name__istartswith=self.q)

        voivodeship = self.forwarded.get("voivodeship", None)
        if voivodeship:
            return qs.filter(parent=voivodeship)
        return qs


class CommunityAutocomplete(autocomplete.Select2QuerySetView):
    def get_result_label(self, result):
        return "{} ({})".format(str(result), str(result.category))

    def get_queryset(self):
        qs = (
            JednostkaAdministracyjna.objects.community()
            .select_related("category")
            .all()
        )

        if self.q:
            qs = qs.filter(name__istartswith=self.q)

        county = self.forwarded.get("county", None)
        if county:
            return qs.filter(parent=county)
        return qs



# Generated by Django 1.10.4 on 2016-12-10 21:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0002_auto_20151216_0201"),
    ]

    operations = [
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="name",
            field=models.CharField(max_length=36, verbose_name="Name"),
        ),
    ]



#!/usr/bin/env python
import os

os.environ["DJANGO_SETTINGS_MODULE"] = "tests.settings"

from django.core import management  # noqa: E402

if __name__ == "__main__":
    management.execute_from_command_line()



import django_filters
from django.shortcuts import get_object_or_404
from django.utils.translation import ugettext_lazy as _

try:
    from django_filters import rest_framework as filters
except ImportError:  # Back-ward compatible for django-rest-framework<3.7
    from rest_framework import filters
from rest_framework import viewsets
from teryt_tree.models import JednostkaAdministracyjna
from teryt_tree.rest_framework_ext.serializers import JednostkaAdministracyjnaSerializer


def custom_area_filter(queryset, _, value):
    if not value:
        return queryset
    return queryset.area(get_object_or_404(JednostkaAdministracyjna, pk=value))


class JednostkaAdministracyjnaFilter(filters.FilterSet):
    area = django_filters.CharFilter(method=custom_area_filter, label=_("Area"))

    class Meta:
        model = JednostkaAdministracyjna
        fields = ["name", "category", "category__level", "area"]


class JednostkaAdministracyjnaViewSet(viewsets.ModelViewSet):
    queryset = (
        JednostkaAdministracyjna.objects.select_related("category")
        .prefetch_related("children")
        .all()
    )
    serializer_class = JednostkaAdministracyjnaSerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_class = JednostkaAdministracyjnaFilter



# Generated by Django 1.10.7 on 2017-07-12 23:35

import autoslug.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0003_auto_20161210_1515"),
    ]

    operations = [
        migrations.CreateModel(
            name="SIMC",
            fields=[
                (
                    "id",
                    models.CharField(max_length=7, primary_key=True, serialize=False),
                ),
                ("name", models.CharField(max_length=100)),
                ("updated_on", models.DateField(verbose_name="Updated date")),
                (
                    "sym_pod",
                    models.ForeignKey(
                        blank=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="teryt_tree.SIMC",
                    ),
                ),
            ],
        ),
        migrations.AlterField(
            model_name="category",
            name="slug",
            field=autoslug.fields.AutoSlugField(editable=False, populate_from="name"),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="slug",
            field=autoslug.fields.AutoSlugField(
                editable=False, populate_from="name", unique=True
            ),
        ),
        migrations.AddField(
            model_name="simc",
            name="terc",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="teryt_tree.JednostkaAdministracyjna",
            ),
        ),
    ]



import argparse

from tqdm import tqdm
from django.core.management.base import BaseCommand, CommandError
from django.db import transaction
from functools import lru_cache
from itertools import islice

try:
    from lxml import etree
except ImportError:
    raise CommandError("Missing dependency. Please, install lxml>=2.3.3")

from teryt_tree.models import Category, JednostkaAdministracyjna


class Command(BaseCommand):
    help = "Creates a data in database base on TERC.xml file."
    PARENT_REDUCE = {2: 0, 4: 2, 7: 4}
    LEVEL_REDUCE = {2: 1, 4: 2, 7: 3}
    FORMAT_MAP = {"nazwa_dod": "nazdod"}

    def add_arguments(self, parser):
        parser.add_argument(
            "--input", type=argparse.FileType("r"), nargs="?", help="Input XML-file"
        )
        parser.add_argument(
            "--old-format",
            dest="old_format",
            action="store_true",
            help="Use format data of teryt.stat.gov.pl",
        )
        parser.add_argument(
            "--limit",
            dest="limit",
            type=int,
            default=5000,
            help="Limit of rows inserted"
        )
        parser.add_argument("--no-progress", dest="no_progress", action="store_false")

    def to_object(self, row, old_format):
        if old_format:
            data = {x.get("name").lower(): x.text for x in row}
        else:
            data = {
                self.FORMAT_MAP.get(x.tag.lower(), x.tag.lower()): (
                    x.text or ""
                ).strip()
                for x in row
            }
        obj = JednostkaAdministracyjna()
        obj.active = True
        obj.id = "".join(data.get(x) or "" for x in ("woj", "pow", "gmi", "rodz"))
        index = len(obj.pk)
        if len(obj.id) > 2:
            obj.parent_id = obj.id[: self.PARENT_REDUCE[index]]
        obj.name = data["nazwa"].title()
        obj.updated_on = data["stan_na"]
        obj.category = self.get_genre(data["nazdod"], self.LEVEL_REDUCE[index])
        return obj

    @lru_cache()
    def get_genre(self, name, level):
        obj, _ = Category.objects.get_or_create(name=name, defaults={"level": level})
        return obj

    def handle(self, no_progress, input, old_format, limit, *args, **options):
        root = etree.parse(input)
        self.stdout.write(
            "Importing started. This may take a few seconds. Please wait a moment.\n"
        )
        with transaction.atomic():
            with JednostkaAdministracyjna.objects.delay_mptt_updates():
                for row in self.get_iter(islice(root.iter("row"), limit), no_progress):
                    item = self.to_object(row, old_format)
                    item.save()

    def get_iter(self, items, no_progress):
        return tqdm(items, file=self.stdout) if no_progress else items



from pkg_resources import get_distribution, DistributionNotFound

try:
    __version__ = get_distribution(__name__).version
except DistributionNotFound:
    # package is not installed
    pass
default_app_config = "teryt_tree.apps.TerytTreeConfig"



import factory
import factory.fuzzy
from teryt_tree import models


class CategoryFactory(factory.django.DjangoModelFactory):
    level = 1
    name = factory.Sequence(lambda n: "category-{}".format(n))

    class Meta:
        model = models.Category


class JednostkaAdministracyjnaFactory(factory.django.DjangoModelFactory):
    name = factory.Sequence(lambda n: "jst-{}".format(n))
    pk = factory.fuzzy.FuzzyText(length=7)
    category = factory.SubFactory(CategoryFactory)
    updated_on = "2015-05-12"
    active = True
    rght = 0
    level = 0

    class Meta:
        model = models.JednostkaAdministracyjna


def factory_jst():
    return JednostkaAdministracyjnaFactory()



# Generated by Django 1.11 on 2019-10-21 00:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0005_auto_20191020_1938"),
    ]

    operations = [
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="level",
            field=models.PositiveIntegerField(db_index=True, editable=False),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="lft",
            field=models.PositiveIntegerField(db_index=True, editable=False),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="rght",
            field=models.PositiveIntegerField(db_index=True, editable=False),
        ),
    ]



DEBUG = True
USE_TZ = True
SECRET_KEY = "pQO26MjmglIoVGG40wrOmYOHYKr2R6EFOhxZHaFwlz6LpLvQ49"
DATABASES = {
    "default": {"ENGINE": "django.db.backends.sqlite3", "NAME": "database.sqlite3"}
}
ROOT_URLCONF = "tests.urls"
INSTALLED_APPS = [
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sites",
    "teryt_tree",
]
SITE_ID = 1
MIDDLEWARE_CLASSES = ()



import os
import tempfile

from django.core.management import call_command
from django.test import TestCase

try:
    from io import StringIO
except ImportError:
    from StringIO import StringIO


class TestCommand(TestCase):
    data_url = {
        "TERC_old.xml": "http://cdn.files.jawne.info.pl/public_html/2017/07/13_01_48_33/TERC.xml",
        "SIMC_old.xml": "http://cdn.files.jawne.info.pl/public_html/2017/07/13_01_48_33/SIMC.xml",
        "TERC.xml": "http://cdn.files.jawne.info.pl/public_html/2017/12/03_05_43_05/TERC_Urzedowy_2017-12-03.xml",
        "SIMC.xml": "http://cdn.files.jawne.info.pl/public_html/2017/12/03_05_43_05/SIMC_Urzedowy_2017-12-03.xml",
    }
    cache_dir = os.environ.get("CACHE_DIR", tempfile.gettempdir())

    @staticmethod
    def _get_url(url):
        try:  # Python 3.x
            import urllib.request

            response = urllib.request.urlopen(url)
        except ImportError:  # Python 2.x
            import urllib2

            response = urllib2.urlopen(url)
        return response.read()

    def setUp(self):
        if not os.path.exists(self.cache_dir):
            os.makedirs(self.cache_dir)

    def download_file(self, kind):
        filepath = os.path.join(self.cache_dir, kind)
        if os.path.exists(filepath):
            print("Reuse file {}\n".format(filepath))
            return open(filepath, "rb")
        fp = open(filepath, "wb")
        print("Download to file {}\n".format(filepath))
        fp.write(self._get_url(self.data_url[kind]))
        fp.flush()
        return fp

    def test_load_commands_for_old_format(self):
        fp = self.download_file("TERC_old.xml")

        call_command(
            "load_terc",
            "--old-format",
            "--input",
            fp.name,
            "--no-progress",
            stdout=StringIO(),
        )

        fp = self.download_file("SIMC_old.xml")
        call_command(
            "load_simc",
            "--old-format",
            "--input",
            fp.name,
            "--no-progress",
            stdout=StringIO(),
        )

    def test_load_commands_for_current_format(self):
        fp = self.download_file("TERC.xml")

        call_command(
            "load_terc", "--input", fp.name, "--no-progress", stdout=StringIO()
        )

        fp = self.download_file("SIMC.xml")
        call_command(
            "load_simc", "--input", fp.name, "--no-progress", stdout=StringIO()
        )



from autocomplete_light import shortcuts as autocomplete_light
from django.utils.encoding import force_text

from .models import JednostkaAdministracyjna


class JednostkaAdministracyjnaAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ["name"]


autocomplete_light.register(
    JednostkaAdministracyjna, JednostkaAdministracyjnaAutocomplete
)


class CommunityAutocomplete(JednostkaAdministracyjnaAutocomplete):
    def choice_label(self, choice):
        return "{parent} > {choice}".format(
            parent=force_text(choice.parent), choice=force_text(choice)
        )

    def choices_for_request(self):
        self.choices = self.choices.filter(category__level=3).select_related("parent")
        return super().choices_for_request()


autocomplete_light.register(JednostkaAdministracyjna, CommunityAutocomplete)



# Generated by Django 2.2.6 on 2019-10-21 00:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0004_auto_20170712_2335"),
    ]

    operations = [
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="level",
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="lft",
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="rght",
            field=models.PositiveIntegerField(editable=False),
        ),
    ]



from autoslug import AutoSlugField

from django.urls import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _
from model_utils import Choices
from mptt.managers import TreeManager
from mptt.models import MPTTModel, TreeForeignKey


class JednostkaAdministracyjnaManager(TreeManager):
    def with_category(self):
        return self.select_related("category")


class JednostkaAdministracyjnaQuerySet(models.QuerySet):
    def voivodeship(self):
        return self.filter(category__level=1)

    def county(self):
        return self.filter(category__level=2)

    def community(self):
        return self.filter(category__level=3)

    def area(self, jst):
        return self.filter(tree_id=jst.tree_id, lft__range=(jst.lft, jst.rght))


class Category(models.Model):
    LEVEL = Choices(
        (1, "voivodeship", _("voivodeship")),
        (2, "county", _("county")),
        (3, "community", _("community")),
    )
    name = models.CharField(max_length=50)
    slug = AutoSlugField(populate_from="name")
    level = models.IntegerField(choices=LEVEL, db_index=True)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _("Category")
        verbose_name_plural = _("Categories")


class JednostkaAdministracyjna(MPTTModel):
    id = models.CharField(max_length=7, primary_key=True)
    parent = TreeForeignKey(
        "self", null=True, blank=True, related_name="children", on_delete=models.CASCADE
    )
    name = models.CharField(_("Name"), max_length=36)
    category = models.ForeignKey(Category, on_delete=models.CASCADE)
    slug = AutoSlugField(populate_from="name", unique=True)
    updated_on = models.DateField(verbose_name=_("Updated date"))
    active = models.BooleanField(default=False)
    objects = JednostkaAdministracyjnaManager.from_queryset(
        JednostkaAdministracyjnaQuerySet
    )()

    def __str__(self):
        return "{}".format(self.name)

    def get_absolute_url(self):
        return reverse("teryt:details", kwargs={"slug": self.slug})

    class MPTTMeta:
        order_insertion_by = ["name"]

    class Meta:
        verbose_name = _("Unit of administrative division")
        verbose_name_plural = _("Units of administrative division")


class SIMC(models.Model):
    id = models.CharField(max_length=7, primary_key=True)
    sym_pod = models.ForeignKey("self", blank=True, on_delete=models.CASCADE)
    terc = models.ForeignKey(JednostkaAdministracyjna, on_delete=models.CASCADE)
    name = models.CharField(max_length=100)
    updated_on = models.DateField(verbose_name=_("Updated date"))

    def __str__(self):
        return "{}".format(self.name)



from rest_framework import serializers

from teryt_tree.models import JednostkaAdministracyjna
from teryt_tree.models import Category


class CategorySerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Category
        fields = ("name", "pk")


class JednostkaAdministracyjnaSerializer(serializers.HyperlinkedModelSerializer):
    teryt = serializers.CharField(source="pk", read_only=True)
    url = serializers.CharField(source="get_absolute_url", read_only=True)
    category = CategorySerializer()
    children = serializers.HyperlinkedRelatedField(
        many=True, read_only=True, view_name="jednostkaadministracyjna-detail"
    )

    class Meta:
        model = JednostkaAdministracyjna
        fields = (
            "url",
            "parent",
            "teryt",
            "children",
            "category",
            "name",
            "updated_on",
            "active",
            "level",
        )


# class SIMCSerializer(serializers.HyperlinkedModelSerializer):
#     simc = SIMCSerializer(many=True)
#     sym_pod = SIMCSerializer()
#     terc = JednostkaAdministracyjnaSerializer()

#     class Meta:
#         model = SIMC
#         fields = ['id', 'sym_pod', 'terc', 'name', 'updated_on']



#!/usr/bin/env python

from setuptools import setup

readme = open("README.rst").read()
history = open("HISTORY.rst").read().replace(".. :changelog:", "")

setup(
    name="django-teryt-tree",
    description="Django-teryt-tree is a Django app that implements TERYT database as tree by django-mptt.",
    long_description=readme + "\n\n" + history,
    author="Adam Dobrawy",
    author_email="naczelnik@jawnosc.tk",
    url="https://github.com/ad-m/django-teryt-tree",
    packages=["teryt_tree"],
    include_package_data=True,
    use_scm_version=True,
    setup_requires=["setuptools_scm", "wheel"],
    install_requires=["django-mptt", "django-model-utils", "django-autoslug", "tqdm"],
    download_url="https://github.com/ad-m/django-teryt-tree/",
    license="BSD",
    zip_safe=False,
    keywords="django-teryt-tree",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: Polish",
        "Framework :: Django",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.0",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
)



import argparse
from datetime import datetime

from django.core.management.base import BaseCommand, CommandError
from functools import lru_cache
from tqdm import tqdm

try:
    from lxml import etree
except ImportError:
    raise CommandError("Missing dependency. Please, install lxml>=2.3.3")

from teryt_tree.models import SIMC, JednostkaAdministracyjna


class Command(BaseCommand):
    help = "Creates a data in database base on SIMC.xml file."

    def add_arguments(self, parser):
        parser.add_argument(
            "--input", nargs="?", type=argparse.FileType("r"), help="Input XML-file"
        )
        parser.add_argument(
            "--old-format",
            dest="old_format",
            action="store_true",
            help="Use format data of teryt.stat.gov.pl",
        )
        parser.add_argument("--no-progress", dest="no_progress", action="store_false")

    @lru_cache()
    def get_terc(self, terc_id):
        return JednostkaAdministracyjna.objects.get(id=terc_id)

    def to_object(self, row, old_format):
        if old_format:
            data = {x.get("name").lower(): x.text for x in row}
        else:
            data = {x.tag.lower(): (x.text or "").strip() for x in row}

        terc_id = "".join(
            data.get(x, "") or "" for x in ("woj", "pow", "gmi", "rodz_gmi")
        )
        terc = self.get_terc(terc_id)
        return SIMC(
            id=data["sym"],
            sym_pod_id=data["sympod"],
            terc=terc,
            updated_on=datetime.strptime(data["stan_na"], "%Y-%m-%d"),
        )

    def handle(self, input, no_progress, old_format, *args, **options):
        root = etree.parse(input)
        self.stdout.write(
            "Importing started. This may take a few seconds. Please wait a moment.\n"
        )
        SIMC.objects.bulk_create(
            self.to_object(x, old_format)
            for x in self.get_iter(root.iter("row"), no_progress)
        )

    def get_iter(self, queryset, no_progress):
        return tqdm(queryset) if no_progress else queryset



#!/usr/bin/env python

"""
test_django-teryt-tree
------------

Tests for `django-teryt-tree` models module.
"""

from django.test import TestCase

from teryt_tree import models

from django.utils.encoding import force_text


class JednostkaAdministracyjnaTestCase(TestCase):
    def test_string_representation(self):
        entry = models.JednostkaAdministracyjna(name="My entry title")
        self.assertEqual(force_text(entry), entry.name)


class CategoryTestCase(TestCase):
    def test_string_representation(self):
        entry = models.Category(name="My entry title")
        self.assertEqual(force_text(entry), entry.name)
